@@ -6,6 +6,8 @@ Public API:
 - create_pipeline_interactions_from_messages: Convert messages to MultiTurnSample.
 """
 
+from datarobot_genai.core.mcp.common import MCPConfig
+
 from .agent import build_llm
 from .agent import create_pipeline_interactions_from_messages
 from .base import CrewAIAgent
@@ -16,4 +18,5 @@ __all__ = [
     "CrewAIAgent",
     "build_llm",
     "create_pipeline_interactions_from_messages",
+    "MCPConfig",
 ]
