@@ -1,11 +1,16 @@
 """LlamaIndex utilities and helpers."""
 
+from datarobot_genai.core.mcp.common import MCPConfig
+
 from .agent import DataRobotLiteLLM
 from .agent import create_pipeline_interactions_from_events
 from .base import LlamaIndexAgent
+from .mcp import load_mcp_tools
 
 __all__ = [
     "DataRobotLiteLLM",
     "create_pipeline_interactions_from_events",
     "LlamaIndexAgent",
+    "load_mcp_tools",
+    "MCPConfig",
 ]
